@@ -1,6 +1,6 @@
 package Mail::BIMI::Indicator;
 # ABSTRACT: Class to model a BIMI indicator
-our $VERSION = '2.20201020.2'; # VERSION
+our $VERSION = '2.20201027.2'; # VERSION
 use 5.20.0;
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -73,6 +73,13 @@ sub data_maybe_compressed($self) {
   return $self->data;
 }
 
+
+sub data_uncompressed_normalized($self) {
+  my $data = $self->data_uncompressed;
+  $data =~ s/\r\n?/\n/g;
+  return $data;
+}
+
 sub _build_data_xml($self) {
   my $xml;
   my $data = $self->data_uncompressed;
@@ -204,7 +211,7 @@ Mail::BIMI::Indicator - Class to model a BIMI indicator
 
 =head1 VERSION
 
-version 2.20201020.2
+version 2.20201027.2
 
 =head1 DESCRIPTION
 
@@ -286,6 +293,10 @@ is=rw
 
 Human readable summary of where this indicator was retrieved from
 
+=head2 warnings
+
+is=rw
+
 =head1 CONSUMES
 
 =over 4
@@ -324,6 +335,10 @@ Maximum permitted HTTP fetch
 
 Synonym for data; returns the data in a maybe compressed format
 
+=head2 I<data_uncompressed_normalized()>
+
+Returns the uncompressed data with normalized line endings
+
 =head2 I<finish()>
 
 Finish and clean up, write cache if enabled.
