@@ -1,6 +1,6 @@
 package Mail::BIMI::Record::Authority;
 # ABSTRACT: Class to model a BIMI authority
-our $VERSION = '2.20201020.2'; # VERSION
+our $VERSION = '2.20201027.2'; # VERSION
 use 5.20.0;
 use Moose;
 use Mail::BIMI::Prelude;
@@ -25,12 +25,6 @@ sub _build_is_authority_valid($self) {
     $self->add_error('INVALID_TRANSPORT_A');
   }
 
-  # Currently .pem implies VMC, and is the only evidence document defined
-  # Expand this as more options become available
-  if ( !( $self->uri =~ /\.pem\?/ || $self->uri =~ /\.pem$/ )) {
-    $self->add_error('INVALID_EXTENSION_A','VMC MUST have .pem extension');
-  }
-
   return 0 if $self->errors->@*;
   return 1;
 }
@@ -82,7 +76,7 @@ Mail::BIMI::Record::Authority - Class to model a BIMI authority
 
 =head1 VERSION
 
-version 2.20201020.2
+version 2.20201027.2
 
 =head1 DESCRIPTION
 
@@ -122,6 +116,10 @@ is=rw
 
 Mail::BIMI::VMC object for this Authority
 
+=head2 warnings
+
+is=rw
+
 =head1 CONSUMES
 
 =over 4
