@@ -1,6 +1,6 @@
 package Mail::BIMI::Role::HasError;
 # ABSTRACT: Class to model an error
-our $VERSION = '2.20201020.2'; # VERSION
+our $VERSION = '2.20201027.2'; # VERSION
 use 5.20.0;
 use Moose::Role;
 use Mail::BIMI::Prelude;
@@ -10,6 +10,7 @@ use Mail::BIMI::Error;
 use Sub::Install;
 
 has errors => ( is => 'rw', isa => 'ArrayRef', lazy => 1, default => sub{return []}, traits => ['Cacheable','CacheSerial'] );
+has warnings => ( is => 'rw', isa => 'ArrayRef', lazy => 1, default => sub{return []}, traits => ['Cacheable'] );
 
 
 
@@ -42,6 +43,11 @@ sub add_error($self,$code,$detail=undef) {
 }
 
 
+sub add_warning($self,$detail) {
+  push $self->warnings->@*, $detail;
+}
+
+
 sub add_error_object($self,$error) {
   if ( ref $error eq 'ARRAY' ) {
     foreach my $suberror ( $error->@* ){
@@ -84,11 +90,11 @@ Mail::BIMI::Role::HasError - Class to model an error
 
 =head1 VERSION
 
-version 2.20201020.2
+version 2.20201027.2
 
 =head1 DESCRIPTION
 
-Role for handling validation errors
+Role for handling validation errors and warnings
 
 =head1 METHODS
 
@@ -104,6 +110,10 @@ De-serialize the errors property for cache storage
 
 Add an error with the given code and optional detail to the current operation.
 
+=head2 I<add_warning($detail)>
+
+Add a warning which may be returned to a validator.
+
 =head2 I<add_error_object($error)>
 
 Add an existing error object, or objects, to the current operation
